@@ -3,6 +3,7 @@ from typing import Any, Callable, Optional, Union
 
 import numpy as np
 import pyarrow as pa
+from numba import prange
 from pandas.core import nanops
 
 from fletcher._compat import njit
@@ -336,3 +337,51 @@ def _merge_valid_bitmaps(a: pa.Array, b: pa.Array) -> np.ndarray:
         )
 
         return result
+
+
+@njit(fastmath=True)
+def _get_new_indptr(self_indptr, indices, new_indptr):
+    for i in range(len(indices)):
+        row = indices[i]
+        new_indptr[i + 1] = new_indptr[i] + self_indptr[row + 1] - self_indptr[row]
+    return new_indptr
+
+
+@njit(fastmath=True, parallel=True)
+def _fill_up_indices(new_indptr, new_indices, self_indices, self_indptr, indices):
+    for i in prange(len(indices)):
+        row = indices[i]
+        size = self_indptr[row + 1] - self_indptr[row]
+        if size > 0:
+            new_indices[new_indptr[i] : new_indptr[i + 1]] = self_indices[
+                self_indptr[row] : self_indptr[row + 1]
+            ]
+
+
+def take_on_pyarrow_list(array, indices):
+    """Return a pyarrow.ListArray or pyarrow.LargeListArray containing only the rows of the given indices."""
+    if len(array.flatten()) == 0:
+        return array.take(pa.array(indices))
+
+    self_indptr, self_indices = map(np.asarray, (array.offsets, array.values))
+    self_indices = self_indices[self_indptr[0] : self_indptr[-1]]  # this is only a view
+    self_indptr = self_indptr - self_indptr[0]  # this will make a copy !
+    self_indptr.setflags(write=0)
+    array.validate()
+
+    length = indices.shape[0]
+
+    # let's start with larger np.int64 dtype to avoid overflow
+    # and yes, it will require a bit more memory ...
+    new_indptr = np.zeros(length + 1, dtype=np.int64)
+    new_indptr = _get_new_indptr(self_indptr, indices, new_indptr)
+    # now we can see if we can downcast
+    if new_indptr[-1] < np.iinfo(np.int32).max:
+        new_indptr = new_indptr.astype(np.int32)
+        pa_type = pa.ListArray
+    else:
+        pa_type = pa.LargeListArray
+
+    new_indices = np.zeros(new_indptr[-1], dtype=self_indices.dtype)
+    _fill_up_indices(new_indptr, new_indices, self_indices, self_indptr, indices)
+    return pa_type.from_arrays(new_indptr, new_indices)
