@@ -412,9 +412,9 @@ class TestBaseInterfaceTests(BaseInterfaceTests):
     @pytest.mark.xfail_by_type_filter(
         [pa.types.is_floating], "NaN and null are handled slightly differently"
     )
-    def test_contains(self, data, data_missing, nulls_fixture):
+    def test_contains(self, data, data_missing):
         if hasattr(BaseInterfaceTests, "test_contains"):
-            BaseInterfaceTests.test_contains(self, data, data_missing, nulls_fixture)
+            BaseInterfaceTests.test_contains(self, data, data_missing)
 
 
 class TestBaseMethodsTests(BaseMethodsTests):
@@ -640,7 +640,13 @@ class TestBaseSetitemTests(BaseSetitemTests):
 
     @xfail_list_setitem_not_implemented
     def test_setitem_empty_indxer(self, data, box_in_series):
-        BaseSetitemTests.test_setitem_empty_indxer(self, data, box_in_series)
+        if hasattr(BaseSetitemTests, "test_setitem_empty_indxer"):
+            BaseSetitemTests.test_setitem_empty_indxer(self, data, box_in_series)
+
+    @xfail_list_setitem_not_implemented
+    def test_setitem_empty_indexer(self, data, box_in_series):
+        if hasattr(BaseSetitemTests, "test_setitem_empty_indexer"):
+            BaseSetitemTests.test_setitem_empty_indexer(self, data, box_in_series)
 
     @xfail_list_setitem_not_implemented
     def test_setitem_sequence_broadcasts(self, data, box_in_series):
